@@ -8,7 +8,7 @@ md2ast <- function(x,
                    yaml = rmarkdown::metadata) {
   tf <- tempfile()
 
-  front_matter <- if (length(yaml) > 0) {
+  front_matter <- if ((length(yaml) > 0) && support_yaml(.from)) {
     yaml::write_yaml(yaml, tf)
     c("---", xfun::read_utf8(tf), "---", "", "")
   }
@@ -20,7 +20,7 @@ md2ast <- function(x,
     to = "json",
     from = .from,
     output = tf,
-    citeproc = !is.null(yaml$bibliography),
+    citeproc = !is.null(yaml$bibliography) || any(grepl("^--bibliography", pandoc_args)),
     options = pandoc_args,
     wd = getwd()
   )
